EXPORTS
	??1CMMFBitmapFrameBuffer@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CMMFBitmapFrameBuffer::~CMMFBitmapFrameBuffer(void)
	??1CMMFChannelAndSampleRateConverterFactory@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CMMFChannelAndSampleRateConverterFactory::~CMMFChannelAndSampleRateConverterFactory(void)
	??1CMMFDataPath@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CMMFDataPath::~CMMFDataPath(void)
	??1CMMFDataPathEventMonitor@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CMMFDataPathEventMonitor::~CMMFDataPathEventMonitor(void)
	??1CMMFDescriptorBuffer@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CMMFDescriptorBuffer::~CMMFDescriptorBuffer(void)
	??1CMMFTransferBuffer@@UAE@XZ @ 6 NONAME ; public: virtual __thiscall CMMFTransferBuffer::~CMMFTransferBuffer(void)
	??1CMMFYUVBuffer@@UAE@XZ @ 7 NONAME ; public: virtual __thiscall CMMFYUVBuffer::~CMMFYUVBuffer(void)
	?AddDataSink@RMMFDataPathProxy@@QAEHPAVMDataSink@@@Z @ 8 NONAME ; public: int __thiscall RMMFDataPathProxy::AddDataSink(class MDataSink *)
	?AddDataSinkL@CMMFDataPath@@UAEXPAVMDataSink@@@Z @ 9 NONAME ; public: virtual void __thiscall CMMFDataPath::AddDataSinkL(class MDataSink *)
	?AddDataSource@RMMFDataPathProxy@@QAEHPAVMDataSource@@@Z @ 10 NONAME ; public: int __thiscall RMMFDataPathProxy::AddDataSource(class MDataSource *)
	?AddDataSourceL@CMMFDataPath@@UAEXPAVMDataSource@@@Z @ 11 NONAME ; public: virtual void __thiscall CMMFDataPath::AddDataSourceL(class MDataSource *)
	?BufferEmptiedL@CMMFDataPath@@UAEXPAVCMMFBuffer@@@Z @ 12 NONAME ; public: virtual void __thiscall CMMFDataPath::BufferEmptiedL(class CMMFBuffer *)
	?BufferFilledL@CMMFDataPath@@UAEXPAVCMMFBuffer@@@Z @ 13 NONAME ; public: virtual void __thiscall CMMFDataPath::BufferFilledL(class CMMFBuffer *)
	?CanCreateSinkBuffer@CMMFDataPath@@UAEHXZ @ 14 NONAME ; public: virtual int __thiscall CMMFDataPath::CanCreateSinkBuffer(void)
	?CanCreateSourceBuffer@CMMFDataPath@@UAEHXZ @ 15 NONAME ; public: virtual int __thiscall CMMFDataPath::CanCreateSourceBuffer(void)
	?CancelReceiveEvents@RMMFSubThreadBase@@QAEHXZ @ 16 NONAME ; public: int __thiscall RMMFSubThreadBase::CancelReceiveEvents(void)
	?ClearPlayWindow@RMMFDataPathProxy@@QAEHXZ @ 17 NONAME ; public: int __thiscall RMMFDataPathProxy::ClearPlayWindow(void)
	?ClearPlayWindowL@CMMFDataPath@@UAEXXZ @ 18 NONAME ; public: virtual void __thiscall CMMFDataPath::ClearPlayWindowL(void)
	?Close@RMMFDataPathProxy@@QAEXXZ @ 19 NONAME ; public: void __thiscall RMMFDataPathProxy::Close(void)
	?ConstructL@CMMFDataPath@@IAEXVTUid@@@Z @ 20 NONAME ; protected: void __thiscall CMMFDataPath::ConstructL(class TUid)
	?ConstructSinkL@CMMFDataPath@@MAEXABVTDesC8@@@Z @ 21 NONAME ; protected: virtual void __thiscall CMMFDataPath::ConstructSinkL(class TDesC8 const &)
	?ConstructSourceL@CMMFDataPath@@MAEXABVTDesC8@@@Z @ 22 NONAME ; protected: virtual void __thiscall CMMFDataPath::ConstructSourceL(class TDesC8 const &)
	?CreateConverterL@CMMFChannelAndSampleRateConverterFactory@@QAEPAVCMMFChannelAndSampleRateConverter@@HHHH@Z @ 23 NONAME ; public: class CMMFChannelAndSampleRateConverter * __thiscall CMMFChannelAndSampleRateConverterFactory::CreateConverterL(int,int,int,int)
	?CreateConverterL@CMMFChannelAndSampleRateConverterFactory@@QAEPAVCMMFChannelAndSampleRateConverter@@XZ @ 24 NONAME ; public: class CMMFChannelAndSampleRateConverter * __thiscall CMMFChannelAndSampleRateConverterFactory::CreateConverterL(void)
	?CreateSinkBufferL@CMMFDataPath@@UAEPAVCMMFBuffer@@VTMediaId@@@Z @ 25 NONAME ; public: virtual class CMMFBuffer * __thiscall CMMFDataPath::CreateSinkBufferL(class TMediaId)
	?CreateSinkBufferL@CMMFDataPath@@UAEPAVCMMFBuffer@@VTMediaId@@AAH@Z @ 26 NONAME ; public: virtual class CMMFBuffer * __thiscall CMMFDataPath::CreateSinkBufferL(class TMediaId,int &)
	?CreateSourceBufferL@CMMFDataPath@@UAEPAVCMMFBuffer@@VTMediaId@@@Z @ 27 NONAME ; public: virtual class CMMFBuffer * __thiscall CMMFDataPath::CreateSourceBufferL(class TMediaId)
	?CreateSourceBufferL@CMMFDataPath@@UAEPAVCMMFBuffer@@VTMediaId@@AAH@Z @ 28 NONAME ; public: virtual class CMMFBuffer * __thiscall CMMFDataPath::CreateSourceBufferL(class TMediaId,int &)
	?CreateSubThread@RMMFDataPathProxy@@QAEHXZ @ 29 NONAME ; public: int __thiscall RMMFDataPathProxy::CreateSubThread(void)
	?DoCancel@CMMFDataPath@@UAEXXZ @ 30 NONAME ; public: virtual void __thiscall CMMFDataPath::DoCancel(void)
	?DoSendEventToClient@CMMFDataPath@@QAEHVTUid@@H@Z @ 31 NONAME ; public: int __thiscall CMMFDataPath::DoSendEventToClient(class TUid,int)
	?EmptyBufferL@CMMFDataPath@@UAEXPAVCMMFBuffer@@PAVMDataSource@@VTMediaId@@@Z @ 32 NONAME ; public: virtual void __thiscall CMMFDataPath::EmptyBufferL(class CMMFBuffer *,class MDataSource *,class TMediaId)
	?FillBufferL@CMMFDataPath@@UAEXPAVCMMFBuffer@@PAVMDataSink@@VTMediaId@@@Z @ 33 NONAME ; public: virtual void __thiscall CMMFDataPath::FillBufferL(class CMMFBuffer *,class MDataSink *,class TMediaId)
	?GetPosition@RMMFDataPathProxy@@QBEHAAVTTimeIntervalMicroSeconds@@@Z @ 34 NONAME ; public: int __thiscall RMMFDataPathProxy::GetPosition(class TTimeIntervalMicroSeconds &)const 
	?LoadDataPath@RMMFDataPathProxy@@QAEHVTMediaId@@@Z @ 35 NONAME ; public: int __thiscall RMMFDataPathProxy::LoadDataPath(class TMediaId)
	?LoadDataPath@RMMFDataPathProxy@@QAEHVTUid@@@Z @ 36 NONAME ; public: int __thiscall RMMFDataPathProxy::LoadDataPath(class TUid)
	?LoadDataPath@RMMFDataPathProxy@@QAEHVTUid@@VTMediaId@@@Z @ 37 NONAME ; public: int __thiscall RMMFDataPathProxy::LoadDataPath(class TUid,class TMediaId)
	?LoadDataPath@RMMFDataPathProxy@@QAEHXZ @ 38 NONAME ; public: int __thiscall RMMFDataPathProxy::LoadDataPath(void)
	?MapOutBuffer@CMMFTransferBuffer@@QAEXXZ @ 39 NONAME ; public: void __thiscall CMMFTransferBuffer::MapOutBuffer(void)
	?NewL@CMMFBitmapFrameBuffer@@SAPAV1@ABVTSize@@W4TDisplayMode@@@Z @ 40 NONAME ; public: static class CMMFBitmapFrameBuffer * __cdecl CMMFBitmapFrameBuffer::NewL(class TSize const &,enum TDisplayMode)
	?NewL@CMMFBitmapFrameBuffer@@SAPAV1@H@Z @ 41 NONAME ; public: static class CMMFBitmapFrameBuffer * __cdecl CMMFBitmapFrameBuffer::NewL(int)
	?NewL@CMMFCodec@@SAPAV1@ABVTFourCC@@0@Z @ 42 NONAME ; public: static class CMMFCodec * __cdecl CMMFCodec::NewL(class TFourCC const &,class TFourCC const &)
	?NewL@CMMFCodec@@SAPAV1@ABVTFourCC@@0ABVTDesC16@@@Z @ 43 NONAME ; public: static class CMMFCodec * __cdecl CMMFCodec::NewL(class TFourCC const &,class TFourCC const &,class TDesC16 const &)
	?NewL@CMMFCodec@@SAPAV1@VTUid@@@Z @ 44 NONAME ; public: static class CMMFCodec * __cdecl CMMFCodec::NewL(class TUid)
	?NewL@CMMFDataBuffer@@SAPAV1@H@Z @ 45 NONAME ; public: static class CMMFDataBuffer * __cdecl CMMFDataBuffer::NewL(int)
	?NewL@CMMFDataBuffer@@SAPAV1@XZ @ 46 NONAME ; public: static class CMMFDataBuffer * __cdecl CMMFDataBuffer::NewL(void)
	?NewL@CMMFDataPath@@SAPAV1@AAVMAsyncEventHandler@@@Z @ 47 NONAME ; public: static class CMMFDataPath * __cdecl CMMFDataPath::NewL(class MAsyncEventHandler &)
	?NewL@CMMFDataPath@@SAPAV1@VTMediaId@@AAVMAsyncEventHandler@@@Z @ 48 NONAME ; public: static class CMMFDataPath * __cdecl CMMFDataPath::NewL(class TMediaId,class MAsyncEventHandler &)
	?NewL@CMMFDataPath@@SAPAV1@VTUid@@AAVMAsyncEventHandler@@@Z @ 49 NONAME ; public: static class CMMFDataPath * __cdecl CMMFDataPath::NewL(class TUid,class MAsyncEventHandler &)
	?NewL@CMMFDataPath@@SAPAV1@VTUid@@VTMediaId@@AAVMAsyncEventHandler@@@Z @ 50 NONAME ; public: static class CMMFDataPath * __cdecl CMMFDataPath::NewL(class TUid,class TMediaId,class MAsyncEventHandler &)
	?NewL@CMMFDataPathEventMonitor@@SAPAV1@AAVMMMFDataPathEventMonitorObserver@@AAVRMMFDataPathProxy@@@Z @ 51 NONAME ; public: static class CMMFDataPathEventMonitor * __cdecl CMMFDataPathEventMonitor::NewL(class MMMFDataPathEventMonitorObserver &,class RMMFDataPathProxy &)
	?NewL@CMMFDescriptorBuffer@@SAPAV1@H@Z @ 52 NONAME ; public: static class CMMFDescriptorBuffer * __cdecl CMMFDescriptorBuffer::NewL(int)
	?NewL@CMMFDescriptorBuffer@@SAPAV1@XZ @ 53 NONAME ; public: static class CMMFDescriptorBuffer * __cdecl CMMFDescriptorBuffer::NewL(void)
	?NewL@CMMFFormatDecode@@SAPAV1@ABVTDesC16@@PAVMDataSource@@0@Z @ 54 NONAME ; public: static class CMMFFormatDecode * __cdecl CMMFFormatDecode::NewL(class TDesC16 const &,class MDataSource *,class TDesC16 const &)
	?NewL@CMMFFormatDecode@@SAPAV1@ABVTDesC8@@PAVMDataSource@@ABVTDesC16@@@Z @ 55 NONAME ; public: static class CMMFFormatDecode * __cdecl CMMFFormatDecode::NewL(class TDesC8 const &,class MDataSource *,class TDesC16 const &)
	?NewL@CMMFFormatDecode@@SAPAV1@PAVMDataSource@@ABVTDesC16@@@Z @ 56 NONAME ; public: static class CMMFFormatDecode * __cdecl CMMFFormatDecode::NewL(class MDataSource *,class TDesC16 const &)
	?NewL@CMMFFormatDecode@@SAPAV1@VTUid@@PAVMDataSource@@@Z @ 57 NONAME ; public: static class CMMFFormatDecode * __cdecl CMMFFormatDecode::NewL(class TUid,class MDataSource *)
	?NewL@CMMFFormatEncode@@SAPAV1@ABVTDesC16@@PAVMDataSink@@0@Z @ 58 NONAME ; public: static class CMMFFormatEncode * __cdecl CMMFFormatEncode::NewL(class TDesC16 const &,class MDataSink *,class TDesC16 const &)
	?NewL@CMMFFormatEncode@@SAPAV1@ABVTDesC8@@PAVMDataSink@@ABVTDesC16@@@Z @ 59 NONAME ; public: static class CMMFFormatEncode * __cdecl CMMFFormatEncode::NewL(class TDesC8 const &,class MDataSink *,class TDesC16 const &)
	?NewL@CMMFFormatEncode@@SAPAV1@PAVMDataSink@@ABVTDesC16@@@Z @ 60 NONAME ; public: static class CMMFFormatEncode * __cdecl CMMFFormatEncode::NewL(class MDataSink *,class TDesC16 const &)
	?NewL@CMMFFormatEncode@@SAPAV1@VTUid@@PAVMDataSink@@@Z @ 61 NONAME ; public: static class CMMFFormatEncode * __cdecl CMMFFormatEncode::NewL(class TUid,class MDataSink *)
	?NewL@CMMFTransferBuffer@@SAPAV1@AAVRTransferWindow@@I@Z @ 62 NONAME ; public: static class CMMFTransferBuffer * __cdecl CMMFTransferBuffer::NewL(class RTransferWindow &,unsigned int)
	?NewL@CMMFYUVBuffer@@SAPAV1@XZ @ 63 NONAME ; public: static class CMMFYUVBuffer * __cdecl CMMFYUVBuffer::NewL(void)
	?Pause@CMMFDataPath@@UAEXXZ @ 64 NONAME ; public: virtual void __thiscall CMMFDataPath::Pause(void)
	?Pause@RMMFDataPathProxy@@QAEHXZ @ 65 NONAME ; public: int __thiscall RMMFDataPathProxy::Pause(void)
	?Play@RMMFDataPathProxy@@QAEHXZ @ 66 NONAME ; public: int __thiscall RMMFDataPathProxy::Play(void)
	?PlayL@CMMFDataPath@@UAEXXZ @ 67 NONAME ; public: virtual void __thiscall CMMFDataPath::PlayL(void)
	?Position@CMMFDataPath@@UBE?AVTTimeIntervalMicroSeconds@@XZ @ 68 NONAME ; public: virtual class TTimeIntervalMicroSeconds  __thiscall CMMFDataPath::Position(void)const 
	?Prime@RMMFDataPathProxy@@QAEHXZ @ 69 NONAME ; public: int __thiscall RMMFDataPathProxy::Prime(void)
	?PrimeL@CMMFDataPath@@UAEXXZ @ 70 NONAME ; public: virtual void __thiscall CMMFDataPath::PrimeL(void)
	?ReAllocBufferL@CMMFDescriptorBuffer@@QAEXH@Z @ 71 NONAME ; public: void __thiscall CMMFDescriptorBuffer::ReAllocBufferL(int)
	?ReceiveEvents@RMMFSubThreadBase@@QAEXAAV?$TPckgBuf@VTMMFEvent@@@@AAVTRequestStatus@@@Z @ 72 NONAME ; public: void __thiscall RMMFSubThreadBase::ReceiveEvents(class TPckgBuf<class TMMFEvent> &,class TRequestStatus &)
	?ResetL@CMMFDataPath@@UAEXXZ @ 73 NONAME ; public: virtual void __thiscall CMMFDataPath::ResetL(void)
	?RunError@CMMFDataPath@@UAEHH@Z @ 74 NONAME ; public: virtual int __thiscall CMMFDataPath::RunError(int)
	?RunL@CMMFDataPath@@UAEXXZ @ 75 NONAME ; public: virtual void __thiscall CMMFDataPath::RunL(void)
	?RunL@CMMFDataPathEventMonitor@@UAEXXZ @ 76 NONAME ; public: virtual void __thiscall CMMFDataPathEventMonitor::RunL(void)
	?SendEventToClient@CMMFDataPath@@EAEHABVTMMFEvent@@@Z @ 77 NONAME ; private: virtual int __thiscall CMMFDataPath::SendEventToClient(class TMMFEvent const &)
	?SetPlayWindow@RMMFDataPathProxy@@QAEHABVTTimeIntervalMicroSeconds@@0@Z @ 78 NONAME ; public: int __thiscall RMMFDataPathProxy::SetPlayWindow(class TTimeIntervalMicroSeconds const &,class TTimeIntervalMicroSeconds const &)
	?SetPlayWindowL@CMMFDataPath@@UAEXABVTTimeIntervalMicroSeconds@@0@Z @ 79 NONAME ; public: virtual void __thiscall CMMFDataPath::SetPlayWindowL(class TTimeIntervalMicroSeconds const &,class TTimeIntervalMicroSeconds const &)
	?SetPosition@RMMFDataPathProxy@@QAEHABVTTimeIntervalMicroSeconds@@@Z @ 80 NONAME ; public: int __thiscall RMMFDataPathProxy::SetPosition(class TTimeIntervalMicroSeconds const &)
	?SetPositionL@CMMFDataPath@@UAEXABVTTimeIntervalMicroSeconds@@@Z @ 81 NONAME ; public: virtual void __thiscall CMMFDataPath::SetPositionL(class TTimeIntervalMicroSeconds const &)
	?Shutdown@RMMFSubThreadBase@@QAEXXZ @ 82 NONAME ; public: void __thiscall RMMFSubThreadBase::Shutdown(void)
	?SinkDataTypeCode@CMMFDataPath@@UAE?AVTFourCC@@VTMediaId@@@Z @ 83 NONAME ; public: virtual class TFourCC  __thiscall CMMFDataPath::SinkDataTypeCode(class TMediaId)
	?SourceDataTypeCode@CMMFDataPath@@UAE?AVTFourCC@@VTMediaId@@@Z @ 84 NONAME ; public: virtual class TFourCC  __thiscall CMMFDataPath::SourceDataTypeCode(class TMediaId)
	?Start@CMMFDataPathEventMonitor@@QAEXXZ @ 85 NONAME ; public: void __thiscall CMMFDataPathEventMonitor::Start(void)
	?State@CMMFDataPath@@UAEHXZ @ 86 NONAME ; public: virtual int __thiscall CMMFDataPath::State(void)
	?State@RMMFDataPathProxy@@QAEHAAH@Z @ 87 NONAME ; public: int __thiscall RMMFDataPathProxy::State(int &)
	?Stop@CMMFDataPath@@UAEXXZ @ 88 NONAME ; public: virtual void __thiscall CMMFDataPath::Stop(void)
	?Stop@RMMFDataPathProxy@@QAEHXZ @ 89 NONAME ; public: int __thiscall RMMFDataPathProxy::Stop(void)
	?TransferWindow@CMMFTransferBuffer@@QAEAAVRTransferWindow@@XZ @ 90 NONAME ; public: class RTransferWindow & __thiscall CMMFTransferBuffer::TransferWindow(void)
	?UpdateTransferWindow@CMMFTransferBuffer@@QAEHAAVRTransferWindow@@I@Z @ 91 NONAME ; public: int __thiscall CMMFTransferBuffer::UpdateTransferWindow(class RTransferWindow &,unsigned int)
	?EndOfData@CMMFDataPath@@MAEXXZ @ 92 NONAME ; protected: virtual void __thiscall CMMFDataPath::EndOfData(void)
	??1CMMFPtrBuffer@@UAE@XZ @ 93 NONAME ; public: virtual __thiscall CMMFPtrBuffer::~CMMFPtrBuffer(void)
	?NewL@CMMFPtrBuffer@@SAPAV1@ABVTPtr8@@@Z @ 94 NONAME ; public: static class CMMFPtrBuffer * __cdecl CMMFPtrBuffer::NewL(class TPtr8 const &)
	?NewL@CMMFPtrBuffer@@SAPAV1@XZ @ 95 NONAME ; public: static class CMMFPtrBuffer * __cdecl CMMFPtrBuffer::NewL(void)
	?SetPtr@CMMFPtrBuffer@@QAEXABVTPtr8@@@Z @ 96 NONAME ; public: void __thiscall CMMFPtrBuffer::SetPtr(class TPtr8 const &)
	?IsFileServerSafe@CMMFBuffer@@SAHVTUid@@@Z @ 97 NONAME ; public: static int __cdecl CMMFBuffer::IsFileServerSafe(class TUid)
	?IsSupportedDataBuffer@CMMFBuffer@@SAHVTUid@@@Z @ 98 NONAME ; public: static int __cdecl CMMFBuffer::IsSupportedDataBuffer(class TUid)
	?NewL@CMMFFormatDecode@@SAPAV1@ABVTDesC16@@PAVMDataSource@@0AAH@Z @ 99 NONAME ; class CMMFFormatDecode * CMMFFormatDecode::NewL(class TDesC16 const &, class MDataSource *, class TDesC16 const &, int &)
	?NewL@CMMFFormatDecode@@SAPAV1@ABVTDesC8@@PAVMDataSource@@ABVTDesC16@@AAH@Z @ 100 NONAME ; class CMMFFormatDecode * CMMFFormatDecode::NewL(class TDesC8 const &, class MDataSource *, class TDesC16 const &, int &)
	?NewL@CMMFFormatDecode@@SAPAV1@PAVMDataSource@@ABVTDesC16@@AAH@Z @ 101 NONAME ; class CMMFFormatDecode * CMMFFormatDecode::NewL(class MDataSource *, class TDesC16 const &, int &)
	?SetBlockLength@CMMFDataPath@@QAEHI@Z @ 102 NONAME ; int CMMFDataPath::SetBlockLength(unsigned int)
	?NewL@CMMFDataPath2@@SAPAV1@AAVMAsyncEventHandler@@@Z @ 103 NONAME ; class CMMFDataPath2 * CMMFDataPath2::NewL(class MAsyncEventHandler &)
	?NewL@CMMFDataPath2@@SAPAV1@VTMediaId@@AAVMAsyncEventHandler@@@Z @ 104 NONAME ; class CMMFDataPath2 * CMMFDataPath2::NewL(class TMediaId, class MAsyncEventHandler &)
	?NewL@CMMFDataPath2@@SAPAV1@VTUid@@AAVMAsyncEventHandler@@@Z @ 105 NONAME ; class CMMFDataPath2 * CMMFDataPath2::NewL(class TUid, class MAsyncEventHandler &)
	?NewL@CMMFDataPath2@@SAPAV1@VTUid@@VTMediaId@@AAVMAsyncEventHandler@@@Z @ 106 NONAME ; class CMMFDataPath2 * CMMFDataPath2::NewL(class TUid, class TMediaId, class MAsyncEventHandler &)
	?RetainRepeatInfo@CMMFDataPath2@@QAEXXZ @ 107 NONAME ; void CMMFDataPath2::RetainRepeatInfo(void)
	?SetDrmProperties@CMMFDataPath2@@QAEXPAVMDataSource@@PAH@Z @ 108 NONAME ; void CMMFDataPath2::SetDrmProperties(class MDataSource *, int *)
	?SetRepeats@CMMFDataPath2@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 109 NONAME ; void CMMFDataPath2::SetRepeats(int, class TTimeIntervalMicroSeconds const &)
	?PreEmptionPause@CMMFDataPath2@@QAEXXZ @ 110 NONAME ; void CMMFDataPath2::PreEmptionPause(void)

